package wayland

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Tablet_v2_client.Zwp_tablet_v2Source

Graphics tablet device.

The zwp_tablet_v2 interface represents one graphics tablet device. The tablet interface itself does not generate events; all events are generated by zwp_tablet_tool_v2 objects when in proximity above a tablet.

A tablet has a number of static characteristics, e.g. device name and pid/vid. These capabilities are sent in an event sequence after the zwp_tablet_seat_v2.tablet_added event. This initial event sequence is terminated by a zwp_tablet_v2.done event.

Sourcetype 'v t = ([ `Zwp_tablet_v2 ], 'v, [ `Client ]) Wayland.Proxy.t

Version 1

Sourceval destroy : [< `V1 | `V2 ] t -> unit

Destroy the tablet object.

This destroys the client's resource for this tablet object.

Version 2

Handlers

Note: Servers will always want to use v1.

Sourceclass virtual +'a v1 : object ... end

Handler for a proxy with version >= 1.

Sourceclass virtual +'a v2 : object ... end

Handler for a proxy with version >= 2.