package wayland

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Class Zwp_tablet_pad_strip_v2.v1Source

Handler for a proxy with version >= 1.

constraint 'a = [< `V1 ]
method private virtual on_set_feedback : [> `V1 ] t -> description:string -> serial:int32 -> unit

Set compositor feedback.

Requests the compositor to use the provided feedback string associated with this strip. This request should be issued immediately after a wp_tablet_pad_group.mode_switch event from the corresponding group is received, or whenever the strip is mapped to a different action. See wp_tablet_pad_group.mode_switch for more details.

Clients are encouraged to provide context-aware descriptions for the actions associated with the strip, and compositors may use this information to offer visual feedback about the button layout (eg. on-screen displays).

The provided string 'description' is a UTF-8 encoded string to be associated with this ring, and is considered user-visible; general internationalization rules apply.

The serial argument will be that of the last wp_tablet_pad_group.mode_switch event received for the group of this strip. Requests providing other serials than the most recent one will be ignored.

method private virtual on_destroy : [> `V1 ] t -> unit

Destroy the strip object.

This destroys the client's resource for this strip object.

method min_version : int32