package wayland

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Class Zwp_primary_selection_device_v1.v1Source

Handler for a proxy with version >= 1.

constraint 'a = [< `V1 ]
method private virtual on_set_selection : [> `V1 ] t -> source: ([ `Zwp_primary_selection_source_v1 ], [> Imports.Zwp_primary_selection_source_v1.versions ], [ `Server ]) Proxy.t option -> serial:int32 -> unit

Set the primary selection.

Replaces the current selection. The previous owner of the primary selection will receive a wp_primary_selection_source.cancelled event.

To unset the selection, set the source to NULL.

method private virtual on_destroy : [> `V1 ] t -> unit

Destroy the primary selection device.

Destroy the primary selection device.

method min_version : int32