package wayland

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wp_primary_selection_unstable_v1_server.Zwp_primary_selection_source_v1Source

Offer to replace the contents of the primary selection.

The source side of a wp_primary_selection_offer, it provides a way to describe the offered data and respond to requests to transfer the requested contents of the primary selection clipboard.

Sourcetype 'v t = ([ `Zwp_primary_selection_source_v1 ], 'v, [ `Server ]) Wayland.Proxy.t

Version 1

Sourceval cancelled : [< `V1 ] t -> unit

Request for primary selection contents was canceled.

This primary selection source is no longer valid. The client should clean up and destroy this primary selection source.

Sourceval send : [< `V1 ] t -> mime_type:string -> fd:Unix.file_descr -> unit

Send the primary selection contents.

Request for the current primary selection contents from the client. Send the specified mime type over the passed file descriptor, then close it.

Handlers

Note: Servers will always want to use v1.

Sourceclass virtual +'a v1 : object ... end

Handler for a proxy with version >= 1.