package wayland

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Xdg_output_unstable_v1_client.Zxdg_output_manager_v1Source

Manage xdg_output objects.

A global factory interface for xdg_output objects.

Sourcetype 'v t = ([ `Zxdg_output_manager_v1 ], 'v, [ `Client ]) Wayland.Proxy.t

Version 1, 2, 3

Sourceval get_xdg_output : ([< `V1 | `V2 | `V3 ] as 'a) t -> [[ `Zxdg_output_v1 ], 'a, [ `Client ]] Wayland.Proxy.Handler.t -> output:([ `Wl_output ], 'b, [ `Client ]) Wayland.Proxy.t -> ([ `Zxdg_output_v1 ], 'a, [ `Client ]) Wayland.Proxy.t

Create an xdg output from a wl_output.

This creates a new xdg_output object for the given wl_output.

Sourceval destroy : [< `V1 | `V2 | `V3 ] t -> unit

Destroy the xdg_output_manager object.

Using this request a client can tell the server that it is not going to use the xdg_output_manager object anymore.

Any objects already created through this instance are not affected.

Handlers

Note: Servers will always want to use v1.

Sourceclass +'a v1 : object ... end

Handler for a proxy with version >= 1.

Sourceclass +'a v2 : object ... end

Handler for a proxy with version >= 2.

Sourceclass +'a v3 : object ... end

Handler for a proxy with version >= 3.