package wayland

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Wl_output.TransformSource

Transformation applied to buffer contents.

This describes transformations that clients and compositors apply to buffer contents.

The flipped values correspond to an initial flip around a vertical axis followed by rotation.

The purpose is mainly to allow clients to render accordingly and tell the compositor, so that for fullscreen surfaces, the compositor will still be able to scan out directly from client surfaces.

Sourcetype t =
  1. | Normal : t
  2. | V90 : t
  3. | V180 : t
  4. | V270 : t
  5. | Flipped : t
  6. | Flipped_90 : t
  7. | Flipped_180 : t
  8. | Flipped_270 : t
Sourceval to_int32 : t -> int32
Sourceval of_int32 : int32 -> t